Gauge Python |Documentation Status| |Snap Build Status| |Travis Build Status|
=============================================================================

Python language runner for `Gauge`_. 

* `Documentation`_
* `Contributing to Gauge-Python`_

Examples
--------

* `Selenium Example`_
* `Selenium and REST API Example`_

Issues
------

If you find any issues or have any feature requests, please file them in the `issue tracker`_.

.. _issue tracker: https://github.com/kashishm/gauge-python/issues

License
-------

The Gauge-Python is an open-sourced software licensed under the `MIT license`_.

.. _Gauge: https://github.com/getgauge/gauge
.. _Documentation: https://gauge-python.readthedocs.org
.. _Contributing to Gauge-Python: https://gauge-python.readthedocs.io/en/latest/contributing.html
.. _MIT license: http://opensource.org/licenses/MIT
.. _Selenium Example: https://github.com/kashishm/gauge-example-python
.. _Selenium and REST API Example: https://angbaird.com/2016/11/09/selenium-and-rest-api-testing-with-gauge/

.. |Documentation Status| image:: https://readthedocs.org/projects/gauge-python/badge/?version=latest
   :target: http://gauge-python.readthedocs.org/en/latest/?badge=latest
.. |Snap Build Status| image:: https://snap-ci.com/kashishm/gauge-python/branch/master/build_image
   :target: https://snap-ci.com/kashishm/gauge-python/branch/master
.. |Travis Build Status| image:: https://travis-ci.org/kashishm/gauge-python.svg?branch=master
   :target: https://travis-ci.org/kashishm/gauge-python